Index: tests/html/audiocontext_test.dart |
diff --git a/tests/html/audiocontext_test.dart b/tests/html/audiocontext_test.dart |
index 62367530bc9897f60f2ce5ff15bbd7f4db6f335d..e2b471e68de8d9156840947d0d7f8bc30dd276a3 100644 |
--- a/tests/html/audiocontext_test.dart |
+++ b/tests/html/audiocontext_test.dart |
@@ -21,10 +21,10 @@ main() { |
ArrayBufferView arrayBufferView = new Float32Array.fromList([]); |
try { |
// Test that native overload is chosen correctly. Native implementation |
// should throw 'SYNTAX_ERR' DOMException because the buffer is empty. |
AudioBuffer buffer = ctx.createBuffer(arrayBufferView.buffer, false); |
} catch (e) { |
- expect(e.code, equals(DOMException.SYNTAX_ERR)); |
+ expect(e.code, equals(DomException.SYNTAX_ERR)); |
} |
}); |
@@ -21,10 +21,10 @@ main() { |
try { |
// Test that native overload is chosen correctly. Native implementation |
- // should throw 'SYNTAX_ERR' DOMException because the buffer is empty. |
+ // should throw 'SYNTAX_ERR' DomException because the buffer is empty. |
AudioBuffer buffer = ctx.createBuffer(arrayBufferView.buffer, false); |
} catch (e) { |